Struct bee_block::address::AliasAddress
source · [−]pub struct AliasAddress(_);Expand description
An alias address.
Implementations
sourceimpl AliasAddress
impl AliasAddress
sourcepub const KIND: u8 = 8u8
pub const KIND: u8 = 8u8
The Address kind of an AliasAddress.
sourcepub const LENGTH: usize = 32usize
pub const LENGTH: usize = 32usize
The length of an AliasAddress.
sourcepub fn new(id: AliasId) -> Self
pub fn new(id: AliasId) -> Self
Creates a new AliasAddress.
sourcepub fn alias_id(&self) -> &AliasId
pub fn alias_id(&self) -> &AliasId
Returns the AliasId of an AliasAddress.
Methods from Deref<Target = AliasId>
Methods from Deref<Target = [u8; 32]>
1.57.0 · sourcepub fn as_slice(&self) -> &[T]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn as_slice(&self) -> &[T]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Returns a slice containing the entire array. Equivalent to &s[..].
sourcepub fn each_ref(&self) -> [&T; N]
🔬This is a nightly-only experimental API. (array_methods)
pub fn each_ref(&self) -> [&T; N]
array_methods)Borrows each element and returns an array of references with the same
size as self.
Example
#![feature(array_methods)]
let floats = [3.1, 2.7, -1.0];
let float_refs: [&f64; 3] = floats.each_ref();
assert_eq!(float_refs, [&3.1, &2.7, &-1.0]);This method is particularly useful if combined with other methods, like
map. This way, you can avoid moving the original
array if its elements are not Copy.
#![feature(array_methods)]
let strings = ["Ferris".to_string(), "♥".to_string(), "Rust".to_string()];
let is_ascii = strings.each_ref().map(|s| s.is_ascii());
assert_eq!(is_ascii, [true, false, true]);
// We can still access the original array: it has not been moved.
assert_eq!(strings.len(), 3);sourcepub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
🔬This is a nightly-only experimental API. (split_array)
pub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
split_array)Divides one array reference into two at an index.
The first will contain all indices from [0, M) (excluding
the index M itself) and the second will contain all
indices from [M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.split_array_ref::<0>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<2>();
assert_eq!(left, &[1, 2]);
assert_eq!(right, &[3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<6>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}sourcepub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
🔬This is a nightly-only experimental API. (split_array)
pub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
split_array)Divides one array reference into two at an index from the end.
The first will contain all indices from [0, N - M) (excluding
the index N - M itself) and the second will contain all
indices from [N - M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.rsplit_array_ref::<0>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}
{
let (left, right) = v.rsplit_array_ref::<2>();
assert_eq!(left, &[1, 2, 3, 4]);
assert_eq!(right, &[5, 6]);
}
{
let (left, right) = v.rsplit_array_ref::<6>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}Trait Implementations
sourceimpl Clone for AliasAddress
impl Clone for AliasAddress
sourcefn clone(&self) -> AliasAddress
fn clone(&self) -> AliasAddress
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for AliasAddress
impl Debug for AliasAddress
sourceimpl Deref for AliasAddress
impl Deref for AliasAddress
sourceimpl<'de> Deserialize<'de> for AliasAddress
impl<'de> Deserialize<'de> for AliasAddress
sourcefn deserialize<D>(deserializer: D) -> Result<AliasAddress, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<AliasAddress, D::Error>where
D: Deserializer<'de>,
sourceimpl Display for AliasAddress
impl Display for AliasAddress
sourceimpl From<&AliasAddress> for AliasAddressDto
impl From<&AliasAddress> for AliasAddressDto
sourcefn from(value: &AliasAddress) -> Self
fn from(value: &AliasAddress) -> Self
sourceimpl From<AliasAddress> for Address
impl From<AliasAddress> for Address
sourcefn from(original: AliasAddress) -> Address
fn from(original: AliasAddress) -> Address
sourceimpl From<AliasId> for AliasAddress
impl From<AliasId> for AliasAddress
sourcefn from(original: AliasId) -> AliasAddress
fn from(original: AliasId) -> AliasAddress
sourceimpl FromStr for AliasAddress
impl FromStr for AliasAddress
sourceimpl Hash for AliasAddress
impl Hash for AliasAddress
sourceimpl Ord for AliasAddress
impl Ord for AliasAddress
sourcefn cmp(&self, other: &AliasAddress) -> Ordering
fn cmp(&self, other: &AliasAddress) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
sourceimpl Packable for AliasAddress
impl Packable for AliasAddress
type UnpackError = <AliasId as Packable>::UnpackError
type UnpackError = <AliasId as Packable>::UnpackError
type UnpackVisitor = <AliasId as Packable>::UnpackVisitor
type UnpackVisitor = <AliasId as Packable>::UnpackVisitor
sourcefn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
fn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
Packer.sourcefn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
fn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
sourceimpl PartialEq<AliasAddress> for AliasAddress
impl PartialEq<AliasAddress> for AliasAddress
sourcefn eq(&self, other: &AliasAddress) -> bool
fn eq(&self, other: &AliasAddress) -> bool
sourceimpl PartialOrd<AliasAddress> for AliasAddress
impl PartialOrd<AliasAddress> for AliasAddress
sourcefn partial_cmp(&self, other: &AliasAddress) -> Option<Ordering>
fn partial_cmp(&self, other: &AliasAddress) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for AliasAddress
impl Serialize for AliasAddress
sourceimpl TryFrom<&AliasAddressDto> for AliasAddress
impl TryFrom<&AliasAddressDto> for AliasAddress
impl Copy for AliasAddress
impl Eq for AliasAddress
impl StructuralEq for AliasAddress
impl StructuralPartialEq for AliasAddress