Struct bee_block::address::NftAddress
source · [−]pub struct NftAddress(_);Expand description
An NFT address.
Implementations
sourceimpl NftAddress
impl NftAddress
Methods from Deref<Target = NftId>
Methods from Deref<Target = [u8; 32]>
1.57.0 · sourcepub fn as_slice(&self) -> &[T]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn as_slice(&self) -> &[T]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Returns a slice containing the entire array. Equivalent to &s[..].
sourcepub fn each_ref(&self) -> [&T; N]
🔬This is a nightly-only experimental API. (array_methods)
pub fn each_ref(&self) -> [&T; N]
array_methods)Borrows each element and returns an array of references with the same
size as self.
Example
#![feature(array_methods)]
let floats = [3.1, 2.7, -1.0];
let float_refs: [&f64; 3] = floats.each_ref();
assert_eq!(float_refs, [&3.1, &2.7, &-1.0]);This method is particularly useful if combined with other methods, like
map. This way, you can avoid moving the original
array if its elements are not Copy.
#![feature(array_methods)]
let strings = ["Ferris".to_string(), "♥".to_string(), "Rust".to_string()];
let is_ascii = strings.each_ref().map(|s| s.is_ascii());
assert_eq!(is_ascii, [true, false, true]);
// We can still access the original array: it has not been moved.
assert_eq!(strings.len(), 3);sourcepub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
🔬This is a nightly-only experimental API. (split_array)
pub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
split_array)Divides one array reference into two at an index.
The first will contain all indices from [0, M) (excluding
the index M itself) and the second will contain all
indices from [M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.split_array_ref::<0>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<2>();
assert_eq!(left, &[1, 2]);
assert_eq!(right, &[3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<6>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}sourcepub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
🔬This is a nightly-only experimental API. (split_array)
pub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
split_array)Divides one array reference into two at an index from the end.
The first will contain all indices from [0, N - M) (excluding
the index N - M itself) and the second will contain all
indices from [N - M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.rsplit_array_ref::<0>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}
{
let (left, right) = v.rsplit_array_ref::<2>();
assert_eq!(left, &[1, 2, 3, 4]);
assert_eq!(right, &[5, 6]);
}
{
let (left, right) = v.rsplit_array_ref::<6>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}Trait Implementations
sourceimpl Clone for NftAddress
impl Clone for NftAddress
sourcefn clone(&self) -> NftAddress
fn clone(&self) -> NftAddress
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for NftAddress
impl Debug for NftAddress
sourceimpl Deref for NftAddress
impl Deref for NftAddress
sourceimpl<'de> Deserialize<'de> for NftAddress
impl<'de> Deserialize<'de> for NftAddress
sourcefn deserialize<D>(deserializer: D) -> Result<NftAddress, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<NftAddress, D::Error>where
D: Deserializer<'de>,
sourceimpl Display for NftAddress
impl Display for NftAddress
sourceimpl From<&NftAddress> for NftAddressDto
impl From<&NftAddress> for NftAddressDto
sourcefn from(value: &NftAddress) -> Self
fn from(value: &NftAddress) -> Self
sourceimpl From<NftAddress> for Address
impl From<NftAddress> for Address
sourcefn from(original: NftAddress) -> Address
fn from(original: NftAddress) -> Address
sourceimpl From<NftId> for NftAddress
impl From<NftId> for NftAddress
sourcefn from(original: NftId) -> NftAddress
fn from(original: NftId) -> NftAddress
sourceimpl FromStr for NftAddress
impl FromStr for NftAddress
sourceimpl Hash for NftAddress
impl Hash for NftAddress
sourceimpl Ord for NftAddress
impl Ord for NftAddress
sourcefn cmp(&self, other: &NftAddress) -> Ordering
fn cmp(&self, other: &NftAddress) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
sourceimpl Packable for NftAddress
impl Packable for NftAddress
type UnpackError = <NftId as Packable>::UnpackError
type UnpackError = <NftId as Packable>::UnpackError
type UnpackVisitor = <NftId as Packable>::UnpackVisitor
type UnpackVisitor = <NftId as Packable>::UnpackVisitor
sourcefn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
fn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
Packer.sourcefn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
fn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
sourceimpl PartialEq<NftAddress> for NftAddress
impl PartialEq<NftAddress> for NftAddress
sourcefn eq(&self, other: &NftAddress) -> bool
fn eq(&self, other: &NftAddress) -> bool
sourceimpl PartialOrd<NftAddress> for NftAddress
impl PartialOrd<NftAddress> for NftAddress
sourcefn partial_cmp(&self, other: &NftAddress) -> Option<Ordering>
fn partial_cmp(&self, other: &NftAddress) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for NftAddress
impl Serialize for NftAddress
sourceimpl TryFrom<&NftAddressDto> for NftAddress
impl TryFrom<&NftAddressDto> for NftAddress
impl Copy for NftAddress
impl Eq for NftAddress
impl StructuralEq for NftAddress
impl StructuralPartialEq for NftAddress