A module that provides types and syntactic validations of inputs.

Modules

Structs

TreasuryInput is an input which references a milestone which generated a TreasuryOutput.
Represents an input referencing an output.

Enums

A generic input supporting different input kinds.

Constants

The maximum number of inputs of a transaction.
The range of valid numbers of inputs of a transaction.
The maximum index of inputs of a transaction.
The range of valid indices of inputs of a transaction.