Structs

Describes an input which references an unspent treasury output to consume.
Describes an input which references an unspent transaction output to consume.

Enums

Describes all the different input types.