Struct bee_block::input::TreasuryInput
source · [−]pub struct TreasuryInput(_);Expand description
TreasuryInput is an input which references a milestone which generated a
TreasuryOutput.
Implementations
sourceimpl TreasuryInput
impl TreasuryInput
sourcepub const KIND: u8 = 1u8
pub const KIND: u8 = 1u8
The input kind of a TreasuryInput.
sourcepub fn new(id: MilestoneId) -> Self
pub fn new(id: MilestoneId) -> Self
Creates a new TreasuryInput.
sourcepub fn milestone_id(&self) -> &MilestoneId
pub fn milestone_id(&self) -> &MilestoneId
Returns the milestones id of a TreasuryInput.
Methods from Deref<Target = MilestoneId>
Methods from Deref<Target = [u8; 32]>
1.57.0 · sourcepub fn as_slice(&self) -> &[T]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn as_slice(&self) -> &[T]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Returns a slice containing the entire array. Equivalent to &s[..].
sourcepub fn each_ref(&self) -> [&T; N]
🔬This is a nightly-only experimental API. (array_methods)
pub fn each_ref(&self) -> [&T; N]
array_methods)Borrows each element and returns an array of references with the same
size as self.
Example
#![feature(array_methods)]
let floats = [3.1, 2.7, -1.0];
let float_refs: [&f64; 3] = floats.each_ref();
assert_eq!(float_refs, [&3.1, &2.7, &-1.0]);This method is particularly useful if combined with other methods, like
map. This way, you can avoid moving the original
array if its elements are not Copy.
#![feature(array_methods)]
let strings = ["Ferris".to_string(), "♥".to_string(), "Rust".to_string()];
let is_ascii = strings.each_ref().map(|s| s.is_ascii());
assert_eq!(is_ascii, [true, false, true]);
// We can still access the original array: it has not been moved.
assert_eq!(strings.len(), 3);sourcepub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
🔬This is a nightly-only experimental API. (split_array)
pub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
split_array)Divides one array reference into two at an index.
The first will contain all indices from [0, M) (excluding
the index M itself) and the second will contain all
indices from [M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.split_array_ref::<0>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<2>();
assert_eq!(left, &[1, 2]);
assert_eq!(right, &[3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<6>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}sourcepub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
🔬This is a nightly-only experimental API. (split_array)
pub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
split_array)Divides one array reference into two at an index from the end.
The first will contain all indices from [0, N - M) (excluding
the index N - M itself) and the second will contain all
indices from [N - M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.rsplit_array_ref::<0>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}
{
let (left, right) = v.rsplit_array_ref::<2>();
assert_eq!(left, &[1, 2, 3, 4]);
assert_eq!(right, &[5, 6]);
}
{
let (left, right) = v.rsplit_array_ref::<6>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}Trait Implementations
sourceimpl Clone for TreasuryInput
impl Clone for TreasuryInput
sourcefn clone(&self) -> TreasuryInput
fn clone(&self) -> TreasuryInput
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for TreasuryInput
impl Debug for TreasuryInput
sourceimpl Deref for TreasuryInput
impl Deref for TreasuryInput
type Target = MilestoneId
type Target = MilestoneId
sourceimpl<'de> Deserialize<'de> for TreasuryInput
impl<'de> Deserialize<'de> for TreasuryInput
sourcefn deserialize<D>(deserializer: D) -> Result<TreasuryInput, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<TreasuryInput, D::Error>where
D: Deserializer<'de>,
sourceimpl Display for TreasuryInput
impl Display for TreasuryInput
sourceimpl From<&TreasuryInput> for TreasuryInputDto
impl From<&TreasuryInput> for TreasuryInputDto
sourcefn from(value: &TreasuryInput) -> Self
fn from(value: &TreasuryInput) -> Self
sourceimpl From<MilestoneId> for TreasuryInput
impl From<MilestoneId> for TreasuryInput
sourcefn from(original: MilestoneId) -> TreasuryInput
fn from(original: MilestoneId) -> TreasuryInput
sourceimpl From<TreasuryInput> for Input
impl From<TreasuryInput> for Input
sourcefn from(original: TreasuryInput) -> Input
fn from(original: TreasuryInput) -> Input
sourceimpl FromStr for TreasuryInput
impl FromStr for TreasuryInput
sourceimpl Hash for TreasuryInput
impl Hash for TreasuryInput
sourceimpl Ord for TreasuryInput
impl Ord for TreasuryInput
sourcefn cmp(&self, other: &TreasuryInput) -> Ordering
fn cmp(&self, other: &TreasuryInput) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
sourceimpl Packable for TreasuryInput
impl Packable for TreasuryInput
type UnpackError = <MilestoneId as Packable>::UnpackError
type UnpackError = <MilestoneId as Packable>::UnpackError
type UnpackVisitor = <MilestoneId as Packable>::UnpackVisitor
type UnpackVisitor = <MilestoneId as Packable>::UnpackVisitor
sourcefn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
fn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
Packer.sourcefn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
fn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
sourceimpl PartialEq<TreasuryInput> for TreasuryInput
impl PartialEq<TreasuryInput> for TreasuryInput
sourcefn eq(&self, other: &TreasuryInput) -> bool
fn eq(&self, other: &TreasuryInput) -> bool
sourceimpl PartialOrd<TreasuryInput> for TreasuryInput
impl PartialOrd<TreasuryInput> for TreasuryInput
sourcefn partial_cmp(&self, other: &TreasuryInput) -> Option<Ordering>
fn partial_cmp(&self, other: &TreasuryInput) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for TreasuryInput
impl Serialize for TreasuryInput
sourceimpl TryFrom<&TreasuryInputDto> for TreasuryInput
impl TryFrom<&TreasuryInputDto> for TreasuryInput
impl Copy for TreasuryInput
impl Eq for TreasuryInput
impl StructuralEq for TreasuryInput
impl StructuralPartialEq for TreasuryInput