A module that provides types and syntactic validations of outputs.

Re-exports

pub use self::alias::AliasOutput;
pub use self::alias::AliasOutputBuilder;
pub use self::basic::BasicOutput;
pub use self::basic::BasicOutputBuilder;
pub use self::feature::Feature;
pub use self::feature::Features;
pub use self::foundry::FoundryOutput;
pub use self::foundry::FoundryOutputBuilder;
pub use self::nft::NftOutput;
pub use self::nft::NftOutputBuilder;
pub use self::unlock_condition::UnlockCondition;
pub use self::unlock_condition::UnlockConditions;

Modules

Structs

TODO.
Defines the unique identifier of a foundry.
Represents a commitment to transaction inputs.
TODO.
The identifier of an Output.
Specifies the current parameters for the byte cost computation.
TODO.
TreasuryOutput is an output which holds the treasury of a network.

Enums

A generic output that can represent different types defining the deposit of funds.

Constants

The maximum number of outputs of a transaction.
The range of valid numbers of outputs of a transaction .
The maximum index of outputs of a transaction.
The range of valid indices of outputs of a transaction .

Traits

A trait to facilitate the computation of the byte cost of block outputs, which is central to dust protection.