pub struct AliasOutputDto {
pub kind: u8,
pub amount: String,
pub native_tokens: Vec<NativeTokenDto>,
pub alias_id: AliasIdDto,
pub state_index: u32,
pub state_metadata: String,
pub foundry_counter: u32,
pub unlock_conditions: Vec<UnlockConditionDto>,
pub features: Vec<FeatureDto>,
pub immutable_features: Vec<FeatureDto>,
}Expand description
Describes an alias account in the ledger that can be controlled by the state and governance controllers.
Fields
kind: u8amount: Stringnative_tokens: Vec<NativeTokenDto>alias_id: AliasIdDtostate_index: u32state_metadata: Stringfoundry_counter: u32unlock_conditions: Vec<UnlockConditionDto>features: Vec<FeatureDto>immutable_features: Vec<FeatureDto>Trait Implementations
sourceimpl Clone for AliasOutputDto
impl Clone for AliasOutputDto
sourcefn clone(&self) -> AliasOutputDto
fn clone(&self) -> AliasOutputDto
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AliasOutputDto
impl Debug for AliasOutputDto
sourceimpl<'de> Deserialize<'de> for AliasOutputDto
impl<'de> Deserialize<'de> for AliasOutputDto
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl From<&AliasOutput> for AliasOutputDto
impl From<&AliasOutput> for AliasOutputDto
sourcefn from(value: &AliasOutput) -> Self
fn from(value: &AliasOutput) -> Self
Converts to this type from the input type.
sourceimpl PartialEq<AliasOutputDto> for AliasOutputDto
impl PartialEq<AliasOutputDto> for AliasOutputDto
sourcefn eq(&self, other: &AliasOutputDto) -> bool
fn eq(&self, other: &AliasOutputDto) -> bool
sourceimpl Serialize for AliasOutputDto
impl Serialize for AliasOutputDto
impl Eq for AliasOutputDto
impl StructuralEq for AliasOutputDto
impl StructuralPartialEq for AliasOutputDto