pub struct AliasOutput { /* private fields */ }Expand description
Describes an alias account in the ledger that can be controlled by the state and governance controllers.
Implementations
sourceimpl AliasOutput
impl AliasOutput
pub fn try_from_dto(
value: &AliasOutputDto,
token_supply: u64
) -> Result<AliasOutput, DtoError>
pub fn try_from_dtos(
amount: OutputBuilderAmountDto,
native_tokens: Option<Vec<NativeTokenDto>>,
alias_id: &AliasIdDto,
state_index: Option<u32>,
state_metadata: Option<Vec<u8>>,
foundry_counter: Option<u32>,
unlock_conditions: Vec<UnlockConditionDto>,
features: Option<Vec<FeatureDto>>,
immutable_features: Option<Vec<FeatureDto>>,
token_supply: u64
) -> Result<AliasOutput, DtoError>
sourceimpl AliasOutput
impl AliasOutput
sourcepub const KIND: u8 = 4u8
pub const KIND: u8 = 4u8
The Output kind of an AliasOutput.
sourcepub const STATE_METADATA_LENGTH_MAX: u16 = 8_192u16
pub const STATE_METADATA_LENGTH_MAX: u16 = 8_192u16
Maximum possible length in bytes of the state metadata.
sourcepub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags = _
pub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags = _
The set of allowed UnlockConditions for an AliasOutput.
sourcepub const ALLOWED_FEATURES: FeatureFlags = _
pub const ALLOWED_FEATURES: FeatureFlags = _
The set of allowed Features for an AliasOutput.
sourcepub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags = _
pub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags = _
The set of allowed immutable Features for an AliasOutput.
sourcepub fn new_with_amount(
amount: u64,
alias_id: AliasId,
token_supply: u64
) -> Result<Self, Error>
pub fn new_with_amount(
amount: u64,
alias_id: AliasId,
token_supply: u64
) -> Result<Self, Error>
Creates a new AliasOutput with a provided amount.
sourcepub fn new_with_minimum_storage_deposit(
alias_id: AliasId,
rent_structure: RentStructure,
token_supply: u64
) -> Result<Self, Error>
pub fn new_with_minimum_storage_deposit(
alias_id: AliasId,
rent_structure: RentStructure,
token_supply: u64
) -> Result<Self, Error>
Creates a new AliasOutput with a provided rent structure.
The amount will be set to the minimum storage deposit.
sourcepub fn build_with_amount(
amount: u64,
alias_id: AliasId
) -> Result<AliasOutputBuilder, Error>
pub fn build_with_amount(
amount: u64,
alias_id: AliasId
) -> Result<AliasOutputBuilder, Error>
Creates a new AliasOutputBuilder with a provided amount.
sourcepub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
alias_id: AliasId
) -> Result<AliasOutputBuilder, Error>
pub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
alias_id: AliasId
) -> Result<AliasOutputBuilder, Error>
Creates a new AliasOutputBuilder with a provided rent structure.
The amount will be set to the minimum storage deposit.
sourcepub fn native_tokens(&self) -> &NativeTokens
pub fn native_tokens(&self) -> &NativeTokens
sourcepub fn state_index(&self) -> u32
pub fn state_index(&self) -> u32
sourcepub fn state_metadata(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn state_metadata(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
sourcepub fn foundry_counter(&self) -> u32
pub fn foundry_counter(&self) -> u32
sourcepub fn unlock_conditions(&self) -> &UnlockConditions
pub fn unlock_conditions(&self) -> &UnlockConditions
sourcepub fn immutable_features(&self) -> &Features
pub fn immutable_features(&self) -> &Features
sourcepub fn state_controller_address(&self) -> &Address
pub fn state_controller_address(&self) -> &Address
sourcepub fn governor_address(&self) -> &Address
pub fn governor_address(&self) -> &Address
sourcepub fn unlock(
&self,
output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>
) -> Result<(), ConflictReason>
pub fn unlock(
&self,
output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>
) -> Result<(), ConflictReason>