pub struct TagFeature(_);Expand description
Makes it possible to tag outputs with an index, so they can be retrieved through an indexer API.
Implementations
sourceimpl TagFeature
impl TagFeature
sourcepub const KIND: u8 = 3u8
pub const KIND: u8 = 3u8
The Feature kind of an TagFeature.
sourcepub const LENGTH_RANGE: RangeInclusive<u8> = _
pub const LENGTH_RANGE: RangeInclusive<u8> = _
Valid lengths for an TagFeature.