pub struct FoundryOutput { /* private fields */ }Expand description
Describes a foundry output that is controlled by an alias.
Implementations
sourceimpl FoundryOutput
impl FoundryOutput
pub fn try_from_dto(
value: &FoundryOutputDto,
token_supply: u64
) -> Result<FoundryOutput, DtoError>
pub fn try_from_dtos(
amount: OutputBuilderAmountDto,
native_tokens: Option<Vec<NativeTokenDto>>,
serial_number: u32,
token_scheme: &TokenSchemeDto,
unlock_conditions: Vec<UnlockConditionDto>,
features: Option<Vec<FeatureDto>>,
immutable_features: Option<Vec<FeatureDto>>,
token_supply: u64
) -> Result<FoundryOutput, DtoError>
sourceimpl FoundryOutput
impl FoundryOutput
sourcepub const KIND: u8 = 5u8
pub const KIND: u8 = 5u8
The Output kind of a FoundryOutput.
sourcepub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags = UnlockConditionFlags::IMMUTABLE_ALIAS_ADDRESS
pub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags = UnlockConditionFlags::IMMUTABLE_ALIAS_ADDRESS
The set of allowed UnlockConditions for a FoundryOutput.
sourcepub const ALLOWED_FEATURES: FeatureFlags = FeatureFlags::METADATA
pub const ALLOWED_FEATURES: FeatureFlags = FeatureFlags::METADATA
The set of allowed Features for a FoundryOutput.
sourcepub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags = FeatureFlags::METADATA
pub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags = FeatureFlags::METADATA
The set of allowed immutable Features for a FoundryOutput.
sourcepub fn new_with_amount(
amount: u64,
serial_number: u32,
token_scheme: TokenScheme,
token_supply: u64
) -> Result<Self, Error>
pub fn new_with_amount(
amount: u64,
serial_number: u32,
token_scheme: TokenScheme,
token_supply: u64
) -> Result<Self, Error>
Creates a new FoundryOutput with a provided amount.
sourcepub fn new_with_minimum_storage_deposit(
serial_number: u32,
token_scheme: TokenScheme,
rent_structure: RentStructure,
token_supply: u64
) -> Result<Self, Error>
pub fn new_with_minimum_storage_deposit(
serial_number: u32,
token_scheme: TokenScheme,
rent_structure: RentStructure,
token_supply: u64
) -> Result<Self, Error>
Creates a new FoundryOutput with a provided rent structure.
The amount will be set to the minimum storage deposit.
sourcepub fn build_with_amount(
amount: u64,
serial_number: u32,
token_scheme: TokenScheme
) -> Result<FoundryOutputBuilder, Error>
pub fn build_with_amount(
amount: u64,
serial_number: u32,
token_scheme: TokenScheme
) -> Result<FoundryOutputBuilder, Error>
Creates a new FoundryOutputBuilder with a provided amount.
sourcepub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
serial_number: u32,
token_scheme: TokenScheme
) -> Result<FoundryOutputBuilder, Error>
pub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
serial_number: u32,
token_scheme: TokenScheme
) -> Result<FoundryOutputBuilder, Error>
Creates a new FoundryOutputBuilder with a provided rent structure.
The amount will be set to the minimum storage deposit.
sourcepub fn native_tokens(&self) -> &NativeTokens
pub fn native_tokens(&self) -> &NativeTokens
sourcepub fn serial_number(&self) -> u32
pub fn serial_number(&self) -> u32
sourcepub fn token_scheme(&self) -> &TokenScheme
pub fn token_scheme(&self) -> &TokenScheme
sourcepub fn unlock_conditions(&self) -> &UnlockConditions
pub fn unlock_conditions(&self) -> &UnlockConditions
sourcepub fn immutable_features(&self) -> &Features
pub fn immutable_features(&self) -> &Features
sourcepub fn alias_address(&self) -> &AliasAddress
pub fn alias_address(&self) -> &AliasAddress
sourcepub fn id(&self) -> FoundryId
pub fn id(&self) -> FoundryId
Returns the FoundryId of the FoundryOutput.
sourcepub fn token_id(&self) -> TokenId
pub fn token_id(&self) -> TokenId
Returns the TokenId of the FoundryOutput.
sourcepub fn unlock(
&self,
_output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>
) -> Result<(), ConflictReason>
pub fn unlock(
&self,
_output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>
) -> Result<(), ConflictReason>