pub struct NftOutput { /* private fields */ }Expand description
Describes an NFT output, a globally unique token with metadata attached.
Implementations
Sourceimpl NftOutput
impl NftOutput
pub fn try_from_dto( value: &NftOutputDto, token_supply: u64, ) -> Result<NftOutput, DtoError>
pub fn try_from_dtos( amount: OutputBuilderAmountDto, native_tokens: Option<Vec<NativeTokenDto>>, nft_id: &NftIdDto, unlock_conditions: Vec<UnlockConditionDto>, features: Option<Vec<FeatureDto>>, immutable_features: Option<Vec<FeatureDto>>, token_supply: u64, ) -> Result<NftOutput, DtoError>
Sourceimpl NftOutput
impl NftOutput
Sourcepub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags
pub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags
The set of allowed UnlockConditions for an NftOutput.
Sourcepub const ALLOWED_FEATURES: FeatureFlags
pub const ALLOWED_FEATURES: FeatureFlags
Sourcepub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags
pub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags
Sourcepub fn new_with_amount(
amount: u64,
nft_id: NftId,
token_supply: u64,
) -> Result<Self, Error>
pub fn new_with_amount( amount: u64, nft_id: NftId, token_supply: u64, ) -> Result<Self, Error>
Creates a new NftOutput with a provided amount.
Sourcepub fn new_with_minimum_storage_deposit(
nft_id: NftId,
rent_structure: RentStructure,
token_supply: u64,
) -> Result<Self, Error>
pub fn new_with_minimum_storage_deposit( nft_id: NftId, rent_structure: RentStructure, token_supply: u64, ) -> Result<Self, Error>
Creates a new NftOutput with a provided rent structure.
The amount will be set to the minimum storage deposit.
Sourcepub fn build_with_amount(
amount: u64,
nft_id: NftId,
) -> Result<NftOutputBuilder, Error>
pub fn build_with_amount( amount: u64, nft_id: NftId, ) -> Result<NftOutputBuilder, Error>
Creates a new NftOutputBuilder with a provided amount.
Sourcepub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
nft_id: NftId,
) -> Result<NftOutputBuilder, Error>
pub fn build_with_minimum_storage_deposit( rent_structure: RentStructure, nft_id: NftId, ) -> Result<NftOutputBuilder, Error>
Creates a new NftOutputBuilder with a provided rent structure.
The amount will be set to the minimum storage deposit.
Sourcepub fn native_tokens(&self) -> &NativeTokens
pub fn native_tokens(&self) -> &NativeTokens
Sourcepub fn unlock_conditions(&self) -> &UnlockConditions
pub fn unlock_conditions(&self) -> &UnlockConditions
Sourcepub fn immutable_features(&self) -> &Features
pub fn immutable_features(&self) -> &Features
Sourcepub fn unlock(
&self,
output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>,
) -> Result<(), ConflictReason>
pub fn unlock( &self, output_id: &OutputId, unlock: &Unlock, inputs: &[(OutputId, &Output)], context: &mut ValidationContext<'_>, ) -> Result<(), ConflictReason>