Struct bee_block::output::SimpleTokenScheme
source · [−]pub struct SimpleTokenScheme { /* private fields */ }Expand description
Implementations
sourceimpl SimpleTokenScheme
impl SimpleTokenScheme
sourcepub const KIND: u8 = 0u8
pub const KIND: u8 = 0u8
The TokenScheme kind of a SimpleTokenScheme.
sourcepub fn new(
minted_tokens: U256,
melted_tokens: U256,
maximum_supply: U256
) -> Result<Self, Error>
pub fn new(
minted_tokens: U256,
melted_tokens: U256,
maximum_supply: U256
) -> Result<Self, Error>
Creates a new SimpleTokenScheme.
sourcepub fn minted_tokens(&self) -> U256
pub fn minted_tokens(&self) -> U256
Returns the number of minted tokens of the SimpleTokenScheme.
sourcepub fn melted_tokens(&self) -> U256
pub fn melted_tokens(&self) -> U256
Returns the number of melted tokens of the SimpleTokenScheme.
sourcepub fn maximum_supply(&self) -> U256
pub fn maximum_supply(&self) -> U256
Returns the maximum supply of the SimpleTokenScheme.
sourcepub fn circulating_supply(&self) -> U256
pub fn circulating_supply(&self) -> U256
Returns the circulating supply of the SimpleTokenScheme.