pub trait Rent {
    fn weighted_bytes(&self, config: &RentStructure) -> u64;

    fn rent_cost(&self, config: &RentStructure) -> u64 { ... }
}
A trait to facilitate the computation of the byte cost of block outputs, which is central to dust protection.

Required Methods

Different fields in a type lead to different storage requirements for the ledger state.

Provided Methods

Computes the rent cost given a RentStructure.

Implementations on Foreign Types

Implementors