pub struct StateControllerAddressUnlockCondition(_);Expand description
Defines the State Controller Address that owns this output, that is, it can unlock it with the proper Unlock in a transaction that state transitions the alias output.
Implementations
sourceimpl StateControllerAddressUnlockCondition
impl StateControllerAddressUnlockCondition
sourcepub const KIND: u8 = 4u8
pub const KIND: u8 = 4u8
The UnlockCondition kind of an StateControllerAddressUnlockCondition.
sourcepub fn new(address: Address) -> Self
pub fn new(address: Address) -> Self
Creates a new StateControllerAddressUnlockCondition.
sourcepub fn address(&self) -> &Address
pub fn address(&self) -> &Address
Returns the address of a StateControllerAddressUnlockCondition.