Struct bee_block::output::unlock_condition::UnlockConditionFlags
source · [−]pub struct UnlockConditionFlags { /* private fields */ }Expand description
A bitflags-based representation of the set of active UnlockConditions.
Implementations
sourceimpl UnlockConditionFlags
impl UnlockConditionFlags
sourcepub const ADDRESS: Self = _
pub const ADDRESS: Self = _
Signals the presence of a AddressUnlockCondition.
sourcepub const STORAGE_DEPOSIT_RETURN: Self = _
pub const STORAGE_DEPOSIT_RETURN: Self = _
Signals the presence of a StorageDepositReturnUnlockCondition.
sourcepub const TIMELOCK: Self = _
pub const TIMELOCK: Self = _
Signals the presence of a TimelockUnlockCondition.
sourcepub const EXPIRATION: Self = _
pub const EXPIRATION: Self = _
Signals the presence of a ExpirationUnlockCondition.
sourcepub const STATE_CONTROLLER_ADDRESS: Self = _
pub const STATE_CONTROLLER_ADDRESS: Self = _
Signals the presence of a StateControllerAddressUnlockCondition.
sourcepub const GOVERNOR_ADDRESS: Self = _
pub const GOVERNOR_ADDRESS: Self = _
Signals the presence of a GovernorAddressUnlockCondition.
sourcepub const IMMUTABLE_ALIAS_ADDRESS: Self = _
pub const IMMUTABLE_ALIAS_ADDRESS: Self = _
Signals the presence of a ImmutableAliasAddressUnlockCondition.
sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u16) -> Self
pub const unsafe fn from_bits_unchecked(bits: u16) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.
sourceimpl UnlockConditionFlags
impl UnlockConditionFlags
sourcepub const ALL_FLAGS: &'static [UnlockConditionFlags] = _
pub const ALL_FLAGS: &'static [UnlockConditionFlags] = _
Returns a slice of all possible base flags.