A module that provides types and syntactic validations of parents. The parents module defines the core data type for storing the blocks directly approved by a block.

Structs

A Block’s Parents are the BlockIds of the blocks it directly approves.