pub struct ReceiptMilestoneOption { /* private fields */ }Expand description
Receipt is a listing of migrated funds.
Implementations
sourceimpl ReceiptMilestoneOption
impl ReceiptMilestoneOption
pub fn try_from_dto(
value: &ReceiptMilestoneOptionDto,
token_supply: u64
) -> Result<ReceiptMilestoneOption, DtoError>
sourceimpl ReceiptMilestoneOption
impl ReceiptMilestoneOption
sourcepub const KIND: u8 = 0u8
pub const KIND: u8 = 0u8
The milestone option kind of a ReceiptMilestoneOption.
sourcepub fn new(
migrated_at: MilestoneIndex,
last: bool,
funds: Vec<MigratedFundsEntry>,
transaction: TreasuryTransactionPayload,
token_supply: u64
) -> Result<Self, Error>
pub fn new(
migrated_at: MilestoneIndex,
last: bool,
funds: Vec<MigratedFundsEntry>,
transaction: TreasuryTransactionPayload,
token_supply: u64
) -> Result<Self, Error>
Creates a new ReceiptMilestoneOption.
sourcepub fn migrated_at(&self) -> MilestoneIndex
pub fn migrated_at(&self) -> MilestoneIndex
Returns the milestone index at which the funds of a ReceiptMilestoneOption were migrated at in the legacy
network.
sourcepub fn last(&self) -> bool
pub fn last(&self) -> bool
Returns whether a ReceiptMilestoneOption is the final one for a given migrated at index.
sourcepub fn funds(&self) -> &[MigratedFundsEntry]
pub fn funds(&self) -> &[MigratedFundsEntry]
The funds which were migrated with a ReceiptMilestoneOption.
sourcepub fn transaction(&self) -> &TreasuryTransactionPayload
pub fn transaction(&self) -> &TreasuryTransactionPayload
The TreasuryTransactionPayload used to
fund the funds of a ReceiptMilestoneOption.
sourcepub fn amount(&self) -> u64
pub fn amount(&self) -> u64
Returns the sum of all MigratedFundsEntry items within a ReceiptMilestoneOption.