Module semantic

Module semantic 

A module that provides types and rules for semantic validation.

Structs

ValidationContext

Enums

ConflictError
Errors related to ledger types.
ConflictReason
Represents the different reasons why a transaction can conflict with the ledger state.

Functions

semantic_validation