pub enum Signature {
Ed25519(Ed25519Signature),
}Expand description
A Signature contains a signature which is used to unlock a transaction input.
This is defined as part of the Unspent Transaction Output (UTXO) transaction protocol.
Variants
Ed25519(Ed25519Signature)
An Ed25519 signature.
Implementations