pub struct NftOutput { /* private fields */ }Expand description
Describes an NFT output, a globally unique token with metadata attached.
Implementations
sourceimpl NftOutput
impl NftOutput
pub fn try_from_dto(
value: &NftOutputDto,
token_supply: u64
) -> Result<NftOutput, DtoError>
pub fn try_from_dtos(
amount: OutputBuilderAmountDto,
native_tokens: Option<Vec<NativeTokenDto>>,
nft_id: &NftIdDto,
unlock_conditions: Vec<UnlockConditionDto>,
features: Option<Vec<FeatureDto>>,
immutable_features: Option<Vec<FeatureDto>>,
token_supply: u64
) -> Result<NftOutput, DtoError>
sourceimpl NftOutput
impl NftOutput
sourcepub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags = _
pub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags = _
The set of allowed UnlockConditions for an NftOutput.
sourcepub const ALLOWED_FEATURES: FeatureFlags = _
pub const ALLOWED_FEATURES: FeatureFlags = _
sourcepub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags = _
pub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags = _
sourcepub fn new_with_amount(
amount: u64,
nft_id: NftId,
token_supply: u64
) -> Result<Self, Error>
pub fn new_with_amount(
amount: u64,
nft_id: NftId,
token_supply: u64
) -> Result<Self, Error>
Creates a new NftOutput with a provided amount.
sourcepub fn new_with_minimum_storage_deposit(
nft_id: NftId,
rent_structure: RentStructure,
token_supply: u64
) -> Result<Self, Error>
pub fn new_with_minimum_storage_deposit(
nft_id: NftId,
rent_structure: RentStructure,
token_supply: u64
) -> Result<Self, Error>
Creates a new NftOutput with a provided rent structure.
The amount will be set to the minimum storage deposit.
sourcepub fn build_with_amount(
amount: u64,
nft_id: NftId
) -> Result<NftOutputBuilder, Error>
pub fn build_with_amount(
amount: u64,
nft_id: NftId
) -> Result<NftOutputBuilder, Error>
Creates a new NftOutputBuilder with a provided amount.
sourcepub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
nft_id: NftId
) -> Result<NftOutputBuilder, Error>
pub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
nft_id: NftId
) -> Result<NftOutputBuilder, Error>
Creates a new NftOutputBuilder with a provided rent structure.
The amount will be set to the minimum storage deposit.
sourcepub fn native_tokens(&self) -> &NativeTokens
pub fn native_tokens(&self) -> &NativeTokens
sourcepub fn unlock_conditions(&self) -> &UnlockConditions
pub fn unlock_conditions(&self) -> &UnlockConditions
sourcepub fn immutable_features(&self) -> &Features
pub fn immutable_features(&self) -> &Features
sourcepub fn unlock(
&self,
output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>
) -> Result<(), ConflictReason>
pub fn unlock(
&self,
output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>
) -> Result<(), ConflictReason>