pub trait Rent {
fn weighted_bytes(&self, config: &RentStructure) -> u64;
fn rent_cost(&self, config: &RentStructure) -> u64 { ... }
}Expand description
A trait to facilitate the computation of the byte cost of block outputs, which is central to dust protection.
Required Methods
sourcefn weighted_bytes(&self, config: &RentStructure) -> u64
fn weighted_bytes(&self, config: &RentStructure) -> u64
Different fields in a type lead to different storage requirements for the ledger state.
Provided Methods
sourcefn rent_cost(&self, config: &RentStructure) -> u64
fn rent_cost(&self, config: &RentStructure) -> u64
Computes the rent cost given a RentStructure.