A module that provides types and syntactic validations of parents. The parents module defines the core data type for storing the blocks directly approved by a block.
A module that provides types and syntactic validations of parents. The parents module defines the core data type for storing the blocks directly approved by a block.