Struct bee_block::payload::OptionalPayload
source · [−]pub struct OptionalPayload(_);Expand description
Methods from Deref<Target = Option<Payload>>
sourcepub fn is_some_and(&self, f: impl FnOnce(&T) -> bool) -> bool
🔬This is a nightly-only experimental API. (is_some_with)
pub fn is_some_and(&self, f: impl FnOnce(&T) -> bool) -> bool
is_some_with)Returns true if the option is a Some and the value inside of it matches a predicate.
Examples
#![feature(is_some_with)]
let x: Option<u32> = Some(2);
assert_eq!(x.is_some_and(|&x| x > 1), true);
let x: Option<u32> = Some(0);
assert_eq!(x.is_some_and(|&x| x > 1), false);
let x: Option<u32> = None;
assert_eq!(x.is_some_and(|&x| x > 1), false);1.0.0 · sourcepub fn as_ref(&self) -> Option<&T>
pub fn as_ref(&self) -> Option<&T>
Converts from &Option<T> to Option<&T>.
Examples
Converts an Option<String> into an Option<usize>, preserving
the original. The map method takes the self argument by value, consuming the original,
so this technique uses as_ref to first take an Option to a reference
to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string());
// First, cast `Option<String>` to `Option<&String>` with `as_ref`,
// then consume *that* with `map`, leaving `text` on the stack.
let text_length: Option<usize> = text.as_ref().map(|s| s.len());
println!("still can print text: {text:?}");1.40.0 · sourcepub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
pub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
Converts from Option<T> (or &Option<T>) to Option<&T::Target>.
Leaves the original Option in-place, creating a new one with a reference
to the original one, additionally coercing the contents via Deref.
Examples
let x: Option<String> = Some("hey".to_owned());
assert_eq!(x.as_deref(), Some("hey"));
let x: Option<String> = None;
assert_eq!(x.as_deref(), None);1.0.0 · sourcepub fn iter(&self) -> Iter<'_, T>
pub fn iter(&self) -> Iter<'_, T>
Returns an iterator over the possibly contained value.
Examples
let x = Some(4);
assert_eq!(x.iter().next(), Some(&4));
let x: Option<u32> = None;
assert_eq!(x.iter().next(), None);sourcepub fn contains<U>(&self, x: &U) -> boolwhere
U: PartialEq<T>,
🔬This is a nightly-only experimental API. (option_result_contains)
pub fn contains<U>(&self, x: &U) -> boolwhere
U: PartialEq<T>,
option_result_contains)Returns true if the option is a Some value containing the given value.
Examples
#![feature(option_result_contains)]
let x: Option<u32> = Some(2);
assert_eq!(x.contains(&2), true);
let x: Option<u32> = Some(3);
assert_eq!(x.contains(&2), false);
let x: Option<u32> = None;
assert_eq!(x.contains(&2), false);Trait Implementations
sourceimpl Clone for OptionalPayload
impl Clone for OptionalPayload
sourcefn clone(&self) -> OptionalPayload
fn clone(&self) -> OptionalPayload
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for OptionalPayload
impl Debug for OptionalPayload
sourceimpl Deref for OptionalPayload
impl Deref for OptionalPayload
sourceimpl<'de> Deserialize<'de> for OptionalPayload
impl<'de> Deserialize<'de> for OptionalPayload
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
sourceimpl From<Option<Payload>> for OptionalPayload
impl From<Option<Payload>> for OptionalPayload
sourceimpl Into<Option<Payload>> for OptionalPayload
impl Into<Option<Payload>> for OptionalPayload
sourceimpl Packable for OptionalPayload
impl Packable for OptionalPayload
type UnpackError = Error
type UnpackError = Error
type UnpackVisitor = ProtocolParameters
type UnpackVisitor = ProtocolParameters
sourcefn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
fn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
Packer.sourcefn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
fn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
sourceimpl PartialEq<OptionalPayload> for OptionalPayload
impl PartialEq<OptionalPayload> for OptionalPayload
sourcefn eq(&self, other: &OptionalPayload) -> bool
fn eq(&self, other: &OptionalPayload) -> bool
sourceimpl Serialize for OptionalPayload
impl Serialize for OptionalPayload
impl Eq for OptionalPayload
impl StructuralEq for OptionalPayload
impl StructuralPartialEq for OptionalPayload