A module that provides types and rules for semantic validation.
Structs
Enums
- Conflict
Error - Errors related to ledger types.
- Conflict
Reason - Represents the different reasons why a transaction can conflict with the ledger state.
A module that provides types and rules for semantic validation.