A module that provides types and rules for semantic validation.

Structs

Enums

Errors related to ledger types.
Represents the different reasons why a transaction can conflict with the ledger state.

Functions