#[repr(u8)]pub enum ConflictReason {
Show 14 variants
None = 0,
InputUtxoAlreadySpent = 1,
InputUtxoAlreadySpentInThisMilestone = 2,
InputUtxoNotFound = 3,
CreatedConsumedAmountMismatch = 4,
InvalidSignature = 5,
TimelockNotExpired = 6,
InvalidNativeTokens = 7,
StorageDepositReturnUnfulfilled = 8,
InvalidUnlock = 9,
InputsCommitmentsMismatch = 10,
UnverifiedSender = 11,
InvalidChainStateTransition = 12,
SemanticValidationFailed = 255,
}Expand description
Represents the different reasons why a transaction can conflict with the ledger state.
Variants
None = 0
The block has no conflict.
InputUtxoAlreadySpent = 1
The referenced Utxo was already spent.
InputUtxoAlreadySpentInThisMilestone = 2
The referenced Utxo was already spent while confirming this milestone.
InputUtxoNotFound = 3
The referenced Utxo cannot be found.
CreatedConsumedAmountMismatch = 4
The created amount does not match the consumed amount.
InvalidSignature = 5
The unlock signature is invalid.
TimelockNotExpired = 6
The configured timelock is not yet expired.
InvalidNativeTokens = 7
The given native tokens are invalid.
StorageDepositReturnUnfulfilled = 8
Storage deposit return mismatch.
InvalidUnlock = 9
An invalid unlock was used.
InputsCommitmentsMismatch = 10
The inputs commitments do not match.
UnverifiedSender = 11
The sender was not verified.
InvalidChainStateTransition = 12
The chain state transition is invalid.
SemanticValidationFailed = 255
The semantic validation failed for a reason not covered by the previous variants.