Enum bee_block::semantic::ConflictReason
source · [−]#[repr(u8)]
pub enum ConflictReason {
Show 14 variants
None,
InputUtxoAlreadySpent,
InputUtxoAlreadySpentInThisMilestone,
InputUtxoNotFound,
CreatedConsumedAmountMismatch,
InvalidSignature,
TimelockNotExpired,
InvalidNativeTokens,
StorageDepositReturnUnfulfilled,
InvalidUnlock,
InputsCommitmentsMismatch,
UnverifiedSender,
InvalidChainStateTransition,
SemanticValidationFailed,
}Expand description
Represents the different reasons why a transaction can conflict with the ledger state.
Variants
None
The block has no conflict.
InputUtxoAlreadySpent
The referenced Utxo was already spent.
InputUtxoAlreadySpentInThisMilestone
The referenced Utxo was already spent while confirming this milestone.
InputUtxoNotFound
The referenced Utxo cannot be found.
CreatedConsumedAmountMismatch
The created amount does not match the consumed amount.
InvalidSignature
The unlock signature is invalid.
TimelockNotExpired
The configured timelock is not yet expired.
InvalidNativeTokens
The given native tokens are invalid.
StorageDepositReturnUnfulfilled
Storage deposit return mismatch.
InvalidUnlock
An invalid unlock was used.
InputsCommitmentsMismatch
The inputs commitments do not match.
UnverifiedSender
The sender was not verified.
InvalidChainStateTransition
The chain state transition is invalid.
SemanticValidationFailed
The semantic validation failed for a reason not covered by the previous variants.